'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LabelSlidingStyled = undefined;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _styledComponents = require('styled-components');

var _styledComponents2 = _interopRequireDefault(_styledComponents);

var _reactackleCore = require('reactackle-core');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var propTypes = {
  disabled: _propTypes2.default.bool,
  /**
   * Full-width TextField doesn't have borders
   */
  fullWidth: _propTypes2.default.bool,
  /**
   * If textfield is dense it has smaller paddings
   */
  dense: _propTypes2.default.bool,
  /**
   * If bordered = false, TextField will have only bottom border
   */
  bordered: _propTypes2.default.bool,
  colorScheme: _propTypes2.default.oneOf(['neutral', 'error', 'success']),
  /**
   * Define label position
   */
  labelPosition: _propTypes2.default.oneOf(['top', 'side']),
  /**
   * If slidingLabel = true, label will float to top
   * when parent textfield is focused or filled
   */
  slidingLabel: _propTypes2.default.bool,
  /**
   * Add icon behind textfield
   */
  iconOuter: _propTypes2.default.element,
  /**
   * Define component theme config
   * See https://github.com/styled-components/styled-components/blob/master/docs/theming.md
   * for more information
   */
  theme: _propTypes2.default.object
};

var defaultProps = {
  disabled: false,
  fullWidth: false,
  dense: false,
  bordered: false,
  colorScheme: 'neutral',
  labelPosition: 'top',
  slidingLabel: false,
  iconOuter: null
};

/** PROP RECEIVERS */
var labelBase = function labelBase(_ref) {
  var themeFromProvider = _ref.theme,
      bordered = _ref.bordered,
      focus = _ref.focus,
      filled = _ref.filled,
      dense = _ref.dense,
      fullWidth = _ref.fullWidth;

  var theme = (0, _reactackleCore.extractThemeOrDefault)(themeFromProvider);
  var textfieldKey = bordered ? 'bordered' : 'underlined';
  var textfieldPath = theme.reactackle.components.textfield.textfield;
  var labelPath = theme.reactackle.components.textfield.label.positionTop;

  var textfieldSource = null;
  if (dense && !fullWidth) textfieldSource = textfieldPath.size.dense;else if (dense && fullWidth) textfieldSource = textfieldPath.size.denseFullWidth;else if (!dense && fullWidth) textfieldSource = textfieldPath.size.fullWidth;else textfieldSource = textfieldPath.size;

  /**
   * When textfield isn't in focus or filled, label should look like TextField's
   * value
   */

  var _ref2 = focus || filled ? labelPath : textfieldSource,
      fontSize = _ref2.fontSize,
      lineHeight = _ref2.lineHeight;

  var borderWidth = (0, _reactackleCore.getValueString)(textfieldPath[textfieldKey].borderWidth);
  var borderWidthSubstraction = bordered ? borderWidth + ' * 2' : borderWidth;

  var _textfieldSource = textfieldSource,
      paddingY = _textfieldSource.paddingY;
  var textTransform = labelPath.textTransform,
      fontWeight = labelPath.fontWeight;


  var filledStyles = '\n    height: auto;\n    bottom: auto;\n    cursor: text;\n    white-space: nowrap;\n    background-color: transparent;\n    top: 0;\n  ';

  var defaultStyles = (0, _styledComponents.css)(['height:calc(100% - ', ');bottom:', ';cursor:default;font-weight:', ';text-transform:', ';align-items:flex-end;padding-bottom:', ';pointer-events:none;'], borderWidthSubstraction, borderWidth, fontWeight, textTransform, (0, _reactackleCore.getValueString)(paddingY));

  return (0, _styledComponents.css)(['font-size:', ';line-height:', ';', ';', ';'], (0, _reactackleCore.getValueString)(fontSize), lineHeight, (0, _reactackleCore.transition)('color, font-size, height'), focus || filled ? filledStyles : defaultStyles);
};

var labelSpacing = function labelSpacing(_ref3) {
  var bordered = _ref3.bordered,
      labelPosition = _ref3.labelPosition,
      dense = _ref3.dense,
      fullWidth = _ref3.fullWidth,
      themeFromProvider = _ref3.theme;

  var theme = (0, _reactackleCore.extractThemeOrDefault)(themeFromProvider);
  var key = labelPosition === 'top' ? 'positionTop' : 'positionSide';
  var labelSizeType = bordered ? 'bordered' : 'underlined';
  var path = theme.reactackle.components.textfield.label[key].size[labelSizeType];
  var source = null;

  if (dense && !fullWidth) source = path.dense;else if (dense && fullWidth) source = path.denseFullWidth;else if (!dense && fullWidth) source = path.fullWidth;else source = path;

  var labelSpacing = (0, _reactackleCore.getValueString)(source.labelSpacing);

  return labelPosition === 'top' ? 'margin-bottom: ' + labelSpacing + ';' : 'margin-right: ' + labelSpacing + ';';
};

var labelStyle = function labelStyle(_ref4) {
  var themeFromProvider = _ref4.theme,
      disabled = _ref4.disabled,
      colorScheme = _ref4.colorScheme,
      labelPosition = _ref4.labelPosition,
      focus = _ref4.focus,
      filled = _ref4.filled;

  var theme = (0, _reactackleCore.extractThemeOrDefault)(themeFromProvider),
      key = labelPosition === 'top' ? 'positionTop' : 'positionSide',
      labelPath = theme.reactackle.components.textfield.label[key].style,
      textfieldPath = theme.reactackle.components.textfield.textfield.state,
      placeholderPath = theme.reactackle.components.textfield.placeholder;

  var labelSource = null,
      textfieldSource = null;

  if (!disabled) {
    if (colorScheme !== 'neutral') {
      labelSource = labelPath[colorScheme];
      textfieldSource = textfieldPath[colorScheme];
    } else if (focus) {
      labelSource = labelPath.focus;
      textfieldSource = textfieldPath.focus;
    } else {
      labelSource = labelPath;
      textfieldSource = textfieldPath;
    }
  } else {
    labelSource = labelPath.disabled;
    textfieldSource = textfieldPath.disabled;
  }

  var _ref5 = focus || filled ? labelSource : placeholderPath,
      fontColor = _ref5.fontColor;

  var textfieldBackgroundColor = (0, _color2.default)(textfieldSource.backgroundColor).alpha() ? textfieldSource : 'white';

  var backgroundColor = focus || filled ? 'transparent' : textfieldBackgroundColor;

  return '\n    background-color: ' + backgroundColor + ';\n    color: ' + fontColor + ';\n  ';
};

var offset = function offset(_ref6) {
  var themeFromProvider = _ref6.theme,
      dense = _ref6.dense,
      fullWidth = _ref6.fullWidth,
      iconOuter = _ref6.iconOuter;

  var theme = (0, _reactackleCore.extractThemeOrDefault)(themeFromProvider);
  var path = theme.reactackle.components.textfield.iconOuter;

  var source = null;
  if (dense && !fullWidth) source = path.size.dense;else if (dense && fullWidth) source = path.size.denseFullWidth;else if (!dense && fullWidth) source = path.size.fullWidth;else source = path.size;

  var iconSpacing = (0, _reactackleCore.getValueString)(path.iconSpacing);
  var boxSize = (0, _reactackleCore.getValueString)(source.boxSize);

  var iconOffset = iconOuter ? 'calc(' + boxSize + ' + ' + iconSpacing + ')' : 0;

  return iconOffset && '\n    left: ' + iconOffset + ';\n    max-width: calc(100% - ' + iconOffset + ');\n  ';
};

/** STYLES */
var LabelSlidingStyled = exports.LabelSlidingStyled = _styledComponents2.default.label.withConfig({
  displayName: 'LabelSlidingStyled'
})(['display:flex;user-select:none;width:100%;position:absolute;z-index:2;justify-content:flex-start;', ';', ';', ';', ';'], labelBase, labelStyle, labelSpacing, offset);

LabelSlidingStyled.propTypes = propTypes;
LabelSlidingStyled.defaultProps = defaultProps;
LabelSlidingStyled.displayName = 'LabelSlidingStyled';